require 'gcc_to_clang_analyzer/rewrite_plist_file'

def spaces_to_tab(s)
  s.gsub('  ', "\t")
end

describe RewritePlistFile do
  it 'should replace the files array with a prefixed version' do
    original = <<-eos
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
  <dict>
    <key>clang_version</key>
    <string>clang version 3.4 (trunk 182989)</string>
    <key>files</key>
    <array>
      <string>src/eeprommanager/main1.cpp</string>
      <string>src/eeprommanager/main2.cpp</string>
    </array>
  </dict>
</plist>
eos
    should_be_plist = <<-eos
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
  <key>clang_version</key>
  <string>clang version 3.4 (trunk 182989)</string>
  <key>files</key>
  <array>
    <string>test/src/eeprommanager/main1.cpp</string>
    <string>test/src/eeprommanager/main2.cpp</string>
  </array>
</dict>
</plist>
eos
    should_be_plist = spaces_to_tab(should_be_plist)
    new_plist = RewritePlistFile.with_prefix('test', original)
    new_plist.should eq(should_be_plist)
  end

  it 'should do nothing for empty file arrays' do
    original = <<-eos
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
  <key>clang_version</key>
  <string>clang version 3.4 (trunk 182989)</string>
  <key>files</key>
  <array> </array>
</dict>
</plist>
eos

    should_be_plist = <<-eos
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
  <key>clang_version</key>
  <string>clang version 3.4 (trunk 182989)</string>
  <key>files</key>
  <array/>
</dict>
</plist>
eos

    should_be_plist = spaces_to_tab(should_be_plist)
    new_file = RewritePlistFile.with_prefix('test', original)
    new_file.should eq(should_be_plist)
  end
end
